"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.wait = exports.mergeDefault = void 0;
/**
 * Merge the default options to user input
 * @param def Default options
 * @param given User input
 * @returns Merged options
 */
function mergeDefault(def, given) {
    if (!given)
        return def;
    const defaultKeys = Object.keys(def);
    for (const key in given) {
        if (defaultKeys.includes(key))
            continue;
        delete given[key];
    }
    for (const key of defaultKeys) {
        if (def[key] === null || (typeof def[key] === 'string' && def[key].length === 0)) {
            if (!given[key])
                throw new Error(`${String(key)} was not found from the given options.`);
        }
        if (given[key] === null || given[key] === undefined)
            given[key] = def[key];
    }
    return given;
}
exports.mergeDefault = mergeDefault;
/**
 * Wait for a specific amount of time (timeout)
 * @param ms Time to wait in milliseconds
 * @returns A promise that resolves in x seconds
 */
function wait(ms) {
    return new Promise(resolve => setTimeout(resolve, ms));
}
exports.wait = wait;
//# sourceMappingURL=Utils.js.map